==> fuioupay-sdk-1.0.0.20240402-20240321.083710-2-sources.jar: com/fshows/steward/response/query/account/FuStdQueryAllocateAccountInDetail.java <==
/**
 * fshows.com
 * Copyright (C) 2013-2024 All Rights Reserved.
 */
package com.fshows.steward.response.query.account;

import lombok.Data;

/**
 * @author wangqilei
 * @version FuStdQueryAllocateAccountInDetail.java, v 0.1 2024-03-21 4:21 PM wangqilei
 */
@Data
public class FuStdQueryAllocateAccountInDetail {
    /**
     * 用户开户请求流水号
     * (必填)
     */
    private String mchntTraceNo;

    /**
     * 用户编号
     * (必填)
     */
    private String accountIn;

    /**
     * 开户银行行号
     * (选填)
     */
    private String interBankNo;

    /**
     * 开户银行名称
     * (必填)
     */
    private String outAcntNm;

    /**
     * 手机号码
     * (必填)
     */
    private String mobile;

    /**
     * 证件号
     * (必填)
     */
    private String licNo;

    /**
     * 分账比例
     * (必填)
     */
    private Integer allocateScale;

    /**
     * 状态
     * 00 协议未签署
     * 01 失效（24 小时失效或
     * 者 3 次签约失效）
     * 02 生效
     * 03 禁用
     * 05 冻结
     * 06 待银行开户
     * (必填)
     */
    private String status;

    /**
     * 银行收款账户号
     * (选填)
     */
    private String bankAcctNo;

    /**
     * 银行账户联行号
     * (选填)
     */
    private String bankInterNo;

    /**
     * 开户银行名称
     * (选填)
     */
    private String bankNm;

    /**
     * 富友收款记账户账号
     * (选填)
     */
    private String depositAccount;

    /**
     * 开户行名称
     * (选填)
     */
    private String issInsName;

    /**
     * 开户省市区
     * (选填)
     */
    private String issCityName;

    /**
     * 支行名称
     * (选填)
     */
    private String subBranchName;

    /**
     * 开户行行号
     * (选填)
     */
    private String fyInterBankNo;
}

==> fuioupay-sdk-1.0.0.20241114.2-20241108.074147-1-sources.jar: com/fshows/steward/response/query/account/FuStdQueryAllocateAccountInDetail.java <==
/**
 * fshows.com
 * Copyright (C) 2013-2024 All Rights Reserved.
 */
package com.fshows.steward.response.query.account;

import lombok.Data;

import java.util.List;

/**
 * @author wangqilei
 * @version FuStdQueryAllocateAccountInDetail.java, v 0.1 2024-03-21 4:21 PM wangqilei
 */
@Data
public class FuStdQueryAllocateAccountInDetail {
    /**
     * 开户请求流水号
     */
    private String mchntTraceNo;

    /**
     * 用户编号
     */
    private String accountIn;

    /**
     * 开户行行号
     */
    private String interBankNo;

    /**
     * 户名
     */
    private String outAcntNm;

    /**
     * 手机号码
     */
    private String mobile;

    /**
     * 证件号
     */
    private String licNo;

    /**
     * 开户银行账号
     */
    private String outAcntNo;

    /**
     * 分账比例
     */
    private Integer allocateScale;

    /**
     * 状态
     * 00 协议未签署
     * 01 失效（24 小时失效或者 3 次签约失效）
     * 02 生效
     * 03 禁用
     * 05 冻结
     * 06 待银行开户
     */
    private String status;

    /**
     * 银行收款账户号
     */
    private String bankAcctNo;

    /**
     * 银行账户联行号
     */
    private String bankInterNo;

    /**
     * 开户银行名称
     */
    private String bankNm;

    /**
     * 富友收款记账户账号
     */
    private String depositAccount;

    /**
     * 开户行名称
     */
    private String issInsName;

    /**
     * 开户省市区
     */
    private String issCityName;

    /**
     * 支行名称
     */
    private String subBranchName;

    /**
     * 开户行行号
     */
    private String fyInterBankNo;

    /**
     * 用户绑卡信息列表
     */
    private List<FuStdQueryAllocateAccountCardDetail> cards;
}
